get_field

Function get_field 

pub fn get_field<T: CurrentTxFieldGetter, F: Into<i32>>(
    field_code: F,
) -> Result<T>
Retrieves a field from the current transaction.

Arguments

  • field_code - The field code identifying which field to retrieve (can be an i32 or SField)

Returns

Returns a Result<T> where:

  • Ok(T) - The field value for the specified field
  • Err(Error) - If the field cannot be retrieved or has unexpected size